WACSplot: Produces validation and/or WACS comparison plots

View source: R/WACSplot.R

WACSplotR Documentation

Produces validation and/or WACS comparison plots

Description

For plotting validation figures from outputs generated when calling WACSvalid or WACScompare. Figures are either displayed or printed in a file

Usage

WACSplot(wacsvalid, file = NULL)

Arguments

wacsvalid

Output, as obtained when calling WACSvalid or WACScompare

file

File in which to write the figure. Default is NULL. If file=NULL, no file is produced; the figure is only produced in the graphical interface

Value

No return. A Figure is either displayed or printed in a file.

Examples

## Not run: 
  ## Simple example
  data(ClimateSeries)
  ThisData = WACSdata(ClimateSeries)
  ThisPar  = WACSestim(ThisData)
  ThisSim  = WACSsimul(ThisPar, from="1995-01-01", to="2012-12-31")
  ThisVal  = WACSvalid(what="Sim",wacsdata = ThisData, wacspar = ThisPar, 
                       wacssimul = ThisSim,varname="tmin")
  WACSplot(ThisVal,file="ThisFile.pdf")

## End(Not run)


WACS documentation built on May 29, 2026, 9:07 a.m.

Related to WACSplot in WACS...