| WACS | R Documentation |
WACS is a multivariate weather generator for daily climate variables based on weather-states that uses a Markov chain for modeling the succession of weather states. Conditionally to the weather states, the multivariate variables are modeled using the family of Complete Skew-Normal distributions. Parameters are estimated on measured series. Must include a 'Rain' variable and can accept as many other variables as desired.
Builds a data structure compatible with WACS functions
Estimation of the parameters of a WACS model
Performs simulations based on estimated parameters of the WACS model
Performs validations of WACS simulations
Performs comparisons between two WACS data structures, or between two WACS simulation series
Plots validation figures from WACSvalid and from WACScompare
Plots fitted bivariate densities of residuals
Denis Allard, Ronan Trépos
Flecher C., Naveau P., Allard D., Brisson N. (2010) A stochastic weather generator for skewed data. Water Resource Research, 46, W07519. Allard D. (2015) WACSgen: model, methods and algorithms. Biostatistiques et Processus Spatiaux, INRA, Avignon, France. Available at denis.biosp.org. Flecher, C., Naveau, Ph. and Allard, D. (2009) Estimating the Closed Skew-Normal distributions parameters using weighted moments. Statistics and Probability Letters, 79, 1977-1984.
Maintainer: Denis Allard denis.allard@inrae.fr (ORCID)
Authors:
Ronan Trepos ronan.trepos@inrae.fr (ORCID)
Useful links:
Report bugs at https://forge.inrae.fr/rtrepos/weathergen/-/issues
## Not run:
data(ClimateSeries)
ThisData = WACSdata(ClimateSeries, from="1995-01-01", to="2012-12-31")
ThisPar = WACSestim(ThisData)
ThisSim = WACSsimul(ThisPar, from="1995-01-01", to="2012-12-31")
ThisVal = WACSvalid(what="Sim",wacsdata = ThisData, wacspar = ThisPar,
wacssimul = ThisSim,varname="tmin")
WACSplot(ThisVal,file="ThisFile.pdf")
## End(Not run)
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.